==> react-final-form-fields-2.0.0.tgz: package/src/components/TextField.js <==
// @flow

import React, { useState } from 'react'
import { Image } from 'react-native'
import styled from 'styled-components/native'
// import * as Masked from 'react-native-imask'

import { DARKEST_GRAY, GRAY } from '../styles/theme'
import Container from './Container'

type CommonProps = {
  children: React.Element,
  input: Object,
  meta?: Object,
  id?: string,
}

type TextFieldProps = {
  ...CommonProps,
  label: string,
  beforeElement?: any,
  onKeyUp?: () => void,
}

type Props = {
  label: String,
  children: React.Element | String,
  input: Object,
  meta: Object,
  className: String,
}

const openEyeIcon = require('../assets/icons/icVisibility.png')
const closedEyeIcon = require('../assets/icons/icVisibility.png')

const Field = styled.TextInput`
  flex: 1;
  height: 44;
  padding-horizontal: 16;
  font-size: 16;
  color: ${DARKEST_GRAY};
  border-width: 1;
  border-style: solid;
  border-radius: 4;
  border-color: ${props => (props.isFocused ? BLUE : props.error ? props.errorTextColor : GRAY)};
`

const FieldContainer = styled.View`
  flex-direction: row;
  background-color: transparent;
  z-index: 0;
`

const EyeContainer = styled.TouchableOpacity`
  width: 20;
  height: 20;
  position: absolute;
  top: 13;
  right: 10;
  z-index: 2;
`

const TextInput = ({
  label,
  input,
  input: { type },
  style,
  placeholder,
  meta,
  meta: { error, touched, dirty },
}: Props) => {
  const fieldId = `TextField_${input.name}`
  let Input
  const [isShowingPassword, setShowPassword] = useState(false)

  switch (type) {
    case 'date':
      Input = <Field {...input} dataDetectorTypes="calendarEvent" keyboardType="number-pad" />
      break

    case 'pin':
      Input = <Field {...input} keyboardType="number-pad" />
      break

    case 'email':
      Input = <Field {...input} keyboardType="email-address" />
      break

    case 'phone':
      Input = (
        <Field
          {...input}
          placeholder={placeholder || '+{62} 00 0000 0000'}
          keyboardType="phone-pad"
          id={fieldId}
          mask="+{62} 00 0000 0000"
        />
      )
      break

    case 'password':
    case 'newPassword':
      Input = (
        <FieldContainer>
          <Field
            {...input}
            textContentType={type}
            id={fieldId}
            style={style}
            placeholder={placeholder}
            secureTextEntry={!isShowingPassword}
          />
          <EyeContainer onPress={() => setShowPassword(!isShowingPassword)}>
            <Image
              style={{ height: 20, width: 20 }}
              source={{ uri: isShowingPassword ? openEyeIcon : closedEyeIcon }}
            />
          </EyeContainer>
        </FieldContainer>
      )
      break

    default: {
      Input = <Field {...input} textContentType={type} id={fieldId} style={style} placeholder={placeholder} />
    }
  }

  return Input
}

function TextField(props: TextFieldProps) {
  const { type, meta } = props
  const fieldId = `TextField_${props.input.name}`

  return (
    <Container {...props} containerStyle={props.containerStyle}>
      {meta.active && props.beforeElement}
      <TextInput onKeyUp={props.onKeyUp} type={type || 'text'} id={fieldId} style={{ width: '100%' }} {...props} />
    </Container>
  )
}

export default TextField

==> react-final-form-fields-2.0.1.tgz: package/src/components/TextField.js <==
// @flow

import React, { useState } from 'react'
import { Image } from 'react-native'
import styled from 'styled-components/native'
// import * as Masked from 'react-native-imask'

import { DARKEST_GRAY, GRAY } from '../styles/theme'
import Container from './Container'

type CommonProps = {
  children: React.Element,
  input: Object,
  meta?: Object,
  id?: string,
}

type TextFieldProps = {
  ...CommonProps,
  label: string,
  beforeElement?: any,
  onKeyUp?: () => void,
}

type Props = {
  label: String,
  children: React.Element | String,
  input: Object,
  meta: Object,
  className: String,
}

const Field = styled.TextInput`
  flex: 1;
  height: 44;
  padding-horizontal: 16;
  font-size: 16;
  color: ${DARKEST_GRAY};
  border-width: 1;
  border-style: solid;
  border-radius: 4;
  border-color: ${props => (props.isFocused ? BLUE : props.error ? props.errorTextColor : GRAY)};
`

const FieldContainer = styled.View`
  flex-direction: row;
  background-color: transparent;
  z-index: 0;
  width: 100%;
`

const EyeContainer = styled.TouchableOpacity`
  width: 20;
  height: 20;
  position: absolute;
  top: 13;
  right: 10;
  z-index: 2;
`

const TextInput = ({
  label,
  input,
  input: { type },
  style,
  placeholder,
  meta,
  meta: { error, touched, dirty },
}: Props) => {
  const fieldId = `TextField_${input.name}`
  let Input
  const [isShowingPassword, setShowPassword] = useState(false)

  switch (type) {
    case 'date':
      Input = <Field {...input} dataDetectorTypes="calendarEvent" keyboardType="number-pad" />
      break

    case 'pin':
      Input = <Field {...input} keyboardType="number-pad" />
      break

    case 'email':
      Input = <Field {...input} keyboardType="email-address" />
      break

    case 'phone':
      Input = (
        <Field
          {...input}
          placeholder={placeholder || '+{62} 00 0000 0000'}
          keyboardType="phone-pad"
          id={fieldId}
          mask="+{62} 00 0000 0000"
        />
      )
      break

    case 'password':
    case 'newPassword':
      Input = (
        <FieldContainer>
          <Field
            {...input}
            textContentType={type}
            id={fieldId}
            style={style}
            placeholder={placeholder}
            secureTextEntry={!isShowingPassword}
          />
          <EyeContainer onPress={() => setShowPassword(!isShowingPassword)}>
            <Image
              style={{ height: 20, width: 20 }}
              source={
                isShowingPassword
                  ? require('../assets/icons/icVisibility.png')
                  : require('../assets/icons/icVisibilityOff.png')
              }
            />
          </EyeContainer>
        </FieldContainer>
      )
      break

    default: {
      Input = <Field {...input} textContentType={type} id={fieldId} style={style} placeholder={placeholder} />
    }
  }

  return Input
}

function TextField(props: TextFieldProps) {
  const { type, meta } = props
  const fieldId = `TextField_${props.input.name}`

  return (
    <Container {...props} containerStyle={props.containerStyle}>
      {meta.active && props.beforeElement}
      <TextInput onKeyUp={props.onKeyUp} type={type || 'text'} id={fieldId} style={{ width: '100%' }} {...props} />
    </Container>
  )
}

export default TextField
